summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libsvn
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:49:56 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:49:56 -0600
commite6aaa3624cc6179b82a9bfff1760e742a669064c (patch)
tree3fed4deb0540d34f85dfb53b02bea7519e66cc6f /kbabel/catalogmanager/libsvn
parent4071ae43ea213cd0f7d5c344c939ebd97d097051 (diff)
downloadtdesdk-e6aaa3624cc6179b82a9bfff1760e742a669064c.tar.gz
tdesdk-e6aaa3624cc6179b82a9bfff1760e742a669064c.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kbabel/catalogmanager/libsvn')
-rw-r--r--kbabel/catalogmanager/libsvn/svndialog.cpp28
-rw-r--r--kbabel/catalogmanager/libsvn/svndialog.h10
-rw-r--r--kbabel/catalogmanager/libsvn/svnhandler.cpp24
-rw-r--r--kbabel/catalogmanager/libsvn/svnhandler.h10
4 files changed, 36 insertions, 36 deletions
diff --git a/kbabel/catalogmanager/libsvn/svndialog.h b/kbabel/catalogmanager/libsvn/svndialog.h
index 4c89a004..4190a172 100644
--- a/kbabel/catalogmanager/libsvn/svndialog.h
+++ b/kbabel/catalogmanager/libsvn/svndialog.h
@@ -48,7 +48,7 @@ class TQString;
class TQStringList;
class TQTextEdit;
// Forwarding KDE classes
-class KProcess;
+class TDEProcess;
class KTempFile;
class KSharedConfig;
@@ -112,11 +112,11 @@ class SVNDialog : public KDialog
/** Slot for executing the SVN Command. */
void slotExecuteCommand( );
/** Slot for processing the stdout of the SVN Command. */
- void slotProcessStdout( KProcess*, char * buffer, int len );
+ void slotProcessStdout( TDEProcess*, char * buffer, int len );
/** Slot for processing the stderr of the SVN Command. */
- void slotProcessStderr( KProcess*, char * buffer, int len );
+ void slotProcessStderr( TDEProcess*, char * buffer, int len );
/** Slot for post-processing after the SVN command is fninished. */
- void slotProcessExited( KProcess * p );
+ void slotProcessExited( TDEProcess * p );
/// Slot for combox having been activated
void slotComboActivated( int );
@@ -131,7 +131,7 @@ class SVNDialog : public KDialog
TQTextEdit * output;
TQCheckBox * autoAddBox;
- KProcess * p;
+ TDEProcess * p;
TQString _commandLine;
TQString _addCommand;
diff --git a/kbabel/catalogmanager/libsvn/svnhandler.h b/kbabel/catalogmanager/libsvn/svnhandler.h
index 22a1f090..4f2cda5c 100644
--- a/kbabel/catalogmanager/libsvn/svnhandler.h
+++ b/kbabel/catalogmanager/libsvn/svnhandler.h
@@ -119,22 +119,22 @@ class SVNOutputCollector: public TQObject
public:
- SVNOutputCollector( KProcess* );
- void setProcess( KProcess* );
+ SVNOutputCollector( TDEProcess* );
+ void setProcess( TDEProcess* );
const TQString& getOutput() const { return m_gatheredOutput; }
const TQString& getStderr() const { return m_stderrOutput; }
const TQString& getStdout() const { return m_stdoutOutput; }
private slots:
- void slotGatherStderr( KProcess*, char*, int );
- void slotGatherStdout( KProcess*, char*, int );
+ void slotGatherStderr( TDEProcess*, char*, int );
+ void slotGatherStdout( TDEProcess*, char*, int );
private:
TQString m_gatheredOutput;
TQString m_stderrOutput;
TQString m_stdoutOutput;
- KProcess* m_process;
+ TDEProcess* m_process;
};
#endif // SVNHANDLER_H
diff --git a/kbabel/catalogmanager/libsvn/svndialog.cpp b/kbabel/catalogmanager/libsvn/svndialog.cpp
index dca25e69..c5f8c24a 100644
--- a/kbabel/catalogmanager/libsvn/svndialog.cpp
+++ b/kbabel/catalogmanager/libsvn/svndialog.cpp
@@ -213,10 +213,10 @@ void SVNDialog::slotExecuteCommand( )
// Nothing to do here.
if ( _commandLine.isEmpty( ) ) return;
- kdDebug() << "Preparing KProcess" << endl;
+ kdDebug() << "Preparing TDEProcess" << endl;
// Create a new shell process
- p = new KProcess;
+ p = new TDEProcess;
p->setUseShell( true, "/bin/sh" );
if ( _cmd == SVN::Commit ) {
@@ -261,7 +261,7 @@ void SVNDialog::slotExecuteCommand( )
}
// Change the command line to have the real name of the temporary file
- _commandLine.replace( "@LOG@FILE@", KProcess::quote( m_tempFile->name() ) );
+ _commandLine.replace( "@LOG@FILE@", TDEProcess::quote( m_tempFile->name() ) );
// Update the list of log messages
if ( !msg.isEmpty() ) {
@@ -277,19 +277,19 @@ void SVNDialog::slotExecuteCommand( )
}
}
// Set the KProcess' command line.
*p << _commandLine;
- connect( p, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ),
- this, TQT_SLOT ( slotProcessStdout( KProcess*, char*, int ) ) );
- connect( p, TQT_SIGNAL( receivedStderr( KProcess*, char*, int ) ),
- this, TQT_SLOT ( slotProcessStderr( KProcess*, char*, int ) ) );
- connect( p, TQT_SIGNAL( processExited( KProcess* ) ),
- this, TQT_SLOT( slotProcessExited( KProcess* ) ) );
+ connect( p, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ),
+ this, TQT_SLOT ( slotProcessStdout( TDEProcess*, char*, int ) ) );
+ connect( p, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ),
+ this, TQT_SLOT ( slotProcessStderr( TDEProcess*, char*, int ) ) );
+ connect( p, TQT_SIGNAL( processExited( TDEProcess* ) ),
+ this, TQT_SLOT( slotProcessExited( TDEProcess* ) ) );
output->append( i18n( "[ Starting command ]" ) );
- if ( p->start( KProcess::NotifyOnExit, KProcess::Communication( KProcess::AllOutput ) ) ) {
+ if ( p->start( TDEProcess::NotifyOnExit, TDEProcess::Communication( TDEProcess::AllOutput ) ) ) {
// Disable the main button (and the log edit if in commit mode) to
// indicate activity.
mainBtn->setEnabled( false );
@@ -302,7 +302,7 @@ void SVNDialog::slotExecuteCommand( )
}
}
-void SVNDialog::slotProcessStdout( KProcess*, char * buffer, int len )
+void SVNDialog::slotProcessStdout( TDEProcess*, char * buffer, int len )
{
output->append( TQString::fromLocal8Bit( buffer, len ) );
// Set the cursor's position at the end of the output.
@@ -313,7 +313,7 @@ void SVNDialog::slotProcessStdout( KProcess*, char * buffer, int len )
_statusOutput += TQString::fromLocal8Bit( buffer, len );
}
-void SVNDialog::slotProcessStderr( KProcess*, char * buffer, int len )
+void SVNDialog::slotProcessStderr( TDEProcess*, char * buffer, int len )
{
// If an error occurs while executing the command display stderr in
// another color.
@@ -324,7 +324,7 @@ void SVNDialog::slotProcessStderr( KProcess*, char * buffer, int len )
output->setCursorPosition( output->lines( ), 0 );
}
-void SVNDialog::slotProcessExited( KProcess * p )
+void SVNDialog::slotProcessExited( TDEProcess * p )
{
if ( p->exitStatus( ) )
output->append( i18n( "[ Exited with status %1 ]" ).arg( p->exitStatus( ) ) );
@@ -277,19 +277,19 @@ void SVNDialog::slotExecuteCommand( )
}
}
- // Set the KProcess' command line.
+ // Set the TDEProcess' command line.
*p << _commandLine;
diff --git a/kbabel/catalogmanager/libsvn/svnhandler.cpp b/kbabel/catalogmanager/libsvn/svnhandler.cpp
index bff097fd..a643f18a 100644
--- a/kbabel/catalogmanager/libsvn/svnhandler.cpp
+++ b/kbabel/catalogmanager/libsvn/svnhandler.cpp
@@ -132,12 +132,12 @@ SVNHandler::FileStatus SVNHandler::fstatus( const TQString& filename ) const
if ( !entries.exists() )
return NOT_IN_SVN;
- KProcess proc;
+ TDEProcess proc;
SVNOutputCollector out( &proc );
proc << "svn" << "status" << "-v" << "--xml" << info.absFilePath();
- if( !proc.start( KProcess::Block, KProcess::Stdout ) )
+ if( !proc.start( TDEProcess::Block, TDEProcess::Stdout ) )
return ERROR_IN_WC;
TQDomDocument doc;
@@ -290,8 +290,8 @@ void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStr
return;
}
// ### TODO: instead of making a TQString, use KProcess directly, so that it cares about quoting.
// ### TODO: use KProcess::setWorkingDirectory instead of using "cd" (therefore allowing to use KProcess without a shell.)
TQString command("cd " + (templates ? _potBaseDir : _poBaseDir) + " && svn ");
switch ( cmd ) {
case SVN::Update:
@@ -503,23 +503,23 @@ bool SVNHandler::isConsideredModified( const FileStatus status ) const
return status == LOCALLY_MODIFIED || status == NOT_IN_SVN;
}
-SVNOutputCollector::SVNOutputCollector( KProcess* p )
+SVNOutputCollector::SVNOutputCollector( TDEProcess* p )
: m_process(0)
{
setProcess( p );
}
-void SVNOutputCollector::setProcess( KProcess* p )
+void SVNOutputCollector::setProcess( TDEProcess* p )
{
if( m_process )
m_process->disconnect( this );
m_process = p;
if( p ) {
- connect( p, TQT_SIGNAL(receivedStdout(KProcess*, char*, int)),
- this, TQT_SLOT(slotGatherStdout(KProcess*, char*, int)) );
- connect( p, TQT_SIGNAL(receivedStderr(KProcess*, char*, int)),
- this, TQT_SLOT(slotGatherStderr(KProcess*, char*, int)) );
+ connect( p, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)),
+ this, TQT_SLOT(slotGatherStdout(TDEProcess*, char*, int)) );
+ connect( p, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)),
+ this, TQT_SLOT(slotGatherStderr(TDEProcess*, char*, int)) );
}
m_gatheredOutput.truncate( 0 );
@@ -527,13 +527,13 @@ void SVNOutputCollector::setProcess( KProcess* p )
m_stdoutOutput.truncate( 0 );
}
-void SVNOutputCollector::slotGatherStderr( KProcess*, char* data, int len )
+void SVNOutputCollector::slotGatherStderr( TDEProcess*, char* data, int len )
{
m_gatheredOutput.append( TQString::fromLocal8Bit( data, len ) );
m_stderrOutput.append( TQString::fromLocal8Bit( data, len ) );
}
-void SVNOutputCollector::slotGatherStdout( KProcess*, char* data, int len )
+void SVNOutputCollector::slotGatherStdout( TDEProcess*, char* data, int len )
{
m_gatheredOutput.append( TQString::fromLocal8Bit( data, len ) );
m_stdoutOutput.append( TQString::fromLocal8Bit( data, len ) );
@@ -290,8 +290,8 @@ void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStr
return;
}
- // ### TODO: instead of making a TQString, use KProcess directly, so that it cares about quoting.
- // ### TODO: use KProcess::setWorkingDirectory instead of using "cd" (therefore allowing to use KProcess without a shell.)
+ // ### TODO: instead of making a TQString, use TDEProcess directly, so that it cares about quoting.
+ // ### TODO: use TDEProcess::setWorkingDirectory instead of using "cd" (therefore allowing to use TDEProcess without a shell.)
TQString command("cd " + (templates ? _potBaseDir : _poBaseDir) + " && svn ");
switch ( cmd ) {